@@ -12,6 +12,7 @@ ROOT_DIR = pathlib.Path(__file__).parent
 NAME = ROOT_DIR.name
 DEFAULT_HOMEPAGE = "Main-Page"
 UNKNOWN_LOCALE = "unknown"
+UNKNOWN_TITLE = "unknown_title"
 
 with open(ROOT_DIR.joinpath("VERSION"), "r") as fh:
     VERSION = fh.read().strip()
@@ -49,6 +50,24 @@ DEFAULT_WIKI_IMAGE_URL = (
     "default_images/WikiNoImage_300x225.jpg"
 )
 
+DEFAULT_USER_IMAGE_URLS = [
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-1.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-2.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-3.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-4.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-5.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-6.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-7.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-8.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/avatar-9.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/"
+    "avatar-10.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/"
+    "avatar-11.standard",
+    "https://assets.cdn.ifixit.com/static/images/avatars/User/ifixit/"
+    "avatar-12.standard",
+]
+
 # Open this URL in the various languages to retrieve labels below
 # https://www.ifixit.com/api/2.0/guides?guideids=219,220,202,206,46465
 DIFFICULTY_VERY_EASY = [
@@ -156,6 +175,12 @@ CATEGORY_LABELS = {
         "replacement_guides": "Replacement Guides",
         "teardown_guides": "Teardowns",
         "disassembly_guides": "Disassembly Guides",
+        "tools": "Tools",
+        "parts": "Parts",
+        "tools_introduction": (
+            "These are some common tools used to work on this device. You might not "
+            "need every tool for every procedure."
+        ),
     },
     "fr": {
         "author": "Auteur: ",
@@ -169,6 +194,13 @@ CATEGORY_LABELS = {
         "replacement_guides": "Tutoriels de remplacement",
         "teardown_guides": "Vues éclatées",
         "disassembly_guides": "Tutoriels de démontage",
+        "tools": "Outils",
+        "parts": "Pièces",
+        "tools_introduction": (
+            "Voici quelques outils couramment utilisés pour travailler sur cet "
+            "appareil. Vous ne devriez pas avoir besoin de tous les outils pour chaque "
+            "procédure."
+        ),
     },
     "pt": {
         "author": "Autor: ",
@@ -182,6 +214,12 @@ CATEGORY_LABELS = {
         "replacement_guides": "Guias de reposição",
         "teardown_guides": "Teardowns",
         "disassembly_guides": "Guias de Desmontagem",
+        "tools": "Ferramentas",
+        "parts": "Peças",
+        "tools_introduction": (
+            "Estas são algumas ferramentas comuns usadas para executar trabalhos neste "
+            "dispositivo. Talvez você não precise usar todas elas em cada procedimento."
+        ),
     },
     "de": {
         "author": "Autor: ",
@@ -195,6 +233,12 @@ CATEGORY_LABELS = {
         "replacement_guides": "Reparaturanleitungen",
         "teardown_guides": "Teardowns",
         "disassembly_guides": "Demontageanleitungen",
+        "tools": "Werkzeuge",
+        "parts": "Ersatzteile",
+        "tools_introduction": (
+            "Es werden einige allgemeine Werkzeuge verwendet, um an diesem Gerät zu "
+            "arbeiten. Du wirst nicht jedes Werkzeug für jeden Vorgang benötigen."
+        ),
     },
     "ko": {
         "author": "작성자: ",
@@ -208,6 +252,9 @@ CATEGORY_LABELS = {
         "replacement_guides": "교체 가이드",
         "teardown_guides": "분해도",
         "disassembly_guides": "분해 안내서",
+        "tools": "도구",
+        "parts": "부품",
+        "tools_introduction": ("해당 기기를 고치는데 사용하는 일반 도구들 입니다. 매 단계에 모든 도구를 사용하지는 않습니다."),
     },
     "zh": {
         "author": "作者: ",
@@ -221,6 +268,9 @@ CATEGORY_LABELS = {
         "replacement_guides": "更换指南",
         "teardown_guides": "拆​解",
         "disassembly_guides": "拆卸指南",
+        "tools": "工具",
+        "parts": "配件",
+        "tools_introduction": ("这是用于在这个设备上工作的一些常用工具。你可能不需要在每个过程中使用到每个工具。"),
     },
     "ru": {
         "author": "Автор: ",
@@ -234,6 +284,13 @@ CATEGORY_LABELS = {
         "replacement_guides": "Инструкции по заменам",
         "teardown_guides": "Разбираем",
         "disassembly_guides": "Инструкции по демонтажу",
+        "tools": "Инструменты",
+        "parts": "Запчасти",
+        "tools_introduction": (
+            "Вот некоторые основные инструменты, используемые для работы на данном "
+            "устройстве. Вам, возможно, не понадобиться каждый инструмент для каждой "
+            "процедуры."
+        ),
     },
     "nl": {
         "author": "Auteur: ",
@@ -247,6 +304,13 @@ CATEGORY_LABELS = {
         "replacement_guides": "Vervangingshandleidingen",
         "teardown_guides": "Demontages",
         "disassembly_guides": "Demontagehandleidingen",
+        "tools": "Gereedschap",
+        "parts": "Onderdelen",
+        "tools_introduction": (
+            "Dit is een aantal algemene gereedschappen dat gebruikt wordt om aan dit"
+            " apparaat te werken. Je hebt niet elk stuk gereedschap voor elke procedure"
+            " nodig."
+        ),
     },
     "ja": {
         "author": "作成者: ",
@@ -260,6 +324,11 @@ CATEGORY_LABELS = {
         "replacement_guides": "交換ガイド",
         "teardown_guides": "分解",
         "disassembly_guides": "分解ガイド",
+        "tools": "ツール",
+        "parts": "パーツ",
+        "tools_introduction": (
+            "以前、このデバイスの修理に使われていた一般的な工具です。修理過程において全部の工具が必要" "とは限りません。"
+        ),
     },
     "tr": {
         "author": "Yazar: ",
@@ -273,6 +342,12 @@ CATEGORY_LABELS = {
         "replacement_guides": "Parça Değişim Kılavuzları",
         "teardown_guides": "Teardown'lar",
         "disassembly_guides": "Söküm Kılavuzları",
+        "tools": "Aletler",
+        "parts": "Parçalar",
+        "tools_introduction": (
+            "Bunlar, bu cihaz için yaygınca kullanılan bazı aletler. Her işlem için "
+            "her alete ihtiyacınız yoktur."
+        ),
     },
     "it": {
         "author": "Autore: ",
@@ -286,6 +361,13 @@ CATEGORY_LABELS = {
         "replacement_guides": "Guide Sostituzione",
         "teardown_guides": "Smontaggi",
         "disassembly_guides": "Guide di smontaggio",
+        "tools": "Strumenti",
+        "parts": "Ricambi",
+        "tools_introduction": (
+            "Questi sono alcuni strumenti di uso comune usati per lavorare su questo "
+            "dispositivo. Potrebbe non essere necessario ogni strumento per ogni "
+            "procedura."
+        ),
     },
     "es": {
         "author": "Autor/a: ",
@@ -299,6 +381,13 @@ CATEGORY_LABELS = {
         "replacement_guides": "Guías de reemplazo",
         "teardown_guides": "Desmontajes",
         "disassembly_guides": "Guías de Desmontaje",
+        "tools": "Herramientas",
+        "parts": "Partes",
+        "tools_introduction": (
+            "Estas son algunas de las herramientas comunes que se utilizaron para "
+            "trabajar en este dispositivo. Es posible que no necesites todas las "
+            "herramientas para cada procedimiento."
+        ),
     },
 }
 
@@ -320,6 +409,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Published: ",
         "teardown": "Teardown",
+        "comments_count_before": "",
+        "comments_count_after": " comments",
+        "comments_count_one": "One comment",
+        "comments_stats_title": "Comments: ",
+        "comments_show_more": "Load more comments",
+        "tools": "Tools",
+        "parts": "Parts",
     },
     "fr": {
         "written_by": "Rédigé par :",
@@ -338,6 +434,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Publication : ",
         "teardown": "Vue éclatée",
+        "comments_count_before": "",
+        "comments_count_after": " commentaires",
+        "comments_count_one": "Un commentaire",
+        "comments_stats_title": "Commentaires : ",
+        "comments_show_more": "Charger plus de commentaires",
+        "tools": "Outils",
+        "parts": "Pièces",
     },
     "pt": {
         "written_by": "Escrito Por:",
@@ -356,6 +459,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Publicado em: ",
         "teardown": "Teardown",
+        "comments_count_before": "",
+        "comments_count_after": " comentários",
+        "comments_count_one": "Um comentário",
+        "comments_stats_title": "Comentários: ",
+        "comments_show_more": "Carregar mais comentários",
+        "tools": "Ferramentas",
+        "parts": "Peças",
     },
     "de": {
         "written_by": "Geschrieben von:",
@@ -374,6 +484,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Veröffentlicht: ",
         "teardown": "Teardown",
+        "comments_count_before": "",
+        "comments_count_after": " Kommentare",
+        "comments_count_one": "Ein Kommentar",
+        "comments_stats_title": "Kommentare: ",
+        "comments_show_more": "Weitere Kommentare anzeigen",
+        "tools": "Werkzeuge",
+        "parts": "Ersatzteile",
     },
     "ko": {
         "written_by": "작성자",
@@ -392,6 +509,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "게시일: ",
         "teardown": "분해도",
+        "comments_count_before": "댓글 ",
+        "comments_count_after": "개",
+        "comments_count_one": "댓글 한 개",
+        "comments_stats_title": "댓글 ",
+        "comments_show_more": "댓글 더 불러오기",
+        "tools": "도구",
+        "parts": "부품",
     },
     "zh": {
         "written_by": "撰写者：",
@@ -410,6 +534,13 @@ GUIDE_LABELS = {
         "member_since_after": "日注册",
         "published": "发布于：",
         "teardown": " 拆解",
+        "comments_count_before": "",
+        "comments_count_after": "条评论",
+        "comments_count_one": "一条评论",
+        "comments_stats_title": "评论: ",
+        "comments_show_more": "显示更多评论",
+        "tools": "工具",
+        "parts": "配件",
     },
     "ru": {
         "written_by": "Автор:",
@@ -428,6 +559,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Опубликовано: ",
         "teardown": "Разбираем",
+        "comments_count_before": "",
+        "comments_count_after": " комментариев",
+        "comments_count_one": "Один комментарий",
+        "comments_stats_title": "Комментарии: ",
+        "comments_show_more": "Загрузить больше комментариев",
+        "tools": "Инструменты",
+        "parts": "Запчасти",
     },
     "nl": {
         "written_by": "Geschreven door:",
@@ -446,6 +584,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Gepubliceerd: ",
         "teardown": "Uit elkaar gehaald",
+        "comments_count_before": "",
+        "comments_count_after": " commentaren",
+        "comments_count_one": "Een commentaar",
+        "comments_stats_title": "Reacties: ",
+        "comments_show_more": "Meer commentaren laden",
+        "tools": "Gereedschap",
+        "parts": "Onderdelen",
     },
     "ja": {
         "written_by": "作成者：",
@@ -464,6 +609,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "公開日: ",
         "teardown": "分解",
+        "comments_count_before": "",
+        "comments_count_after": " 件のコメント",
+        "comments_count_one": "コメント1件",
+        "comments_stats_title": "コメント: ",
+        "comments_show_more": "コメントをさらに表示する",
+        "tools": "ツール",
+        "parts": "パーツ",
     },
     "tr": {
         "written_by": "Yazan:",
@@ -482,6 +634,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Yayımlama: ",
         "teardown": "Teardown",
+        "comments_count_before": "",
+        "comments_count_after": " yorum",
+        "comments_count_one": "Bir yorum",
+        "comments_stats_title": "Yorumlar: ",
+        "comments_show_more": "Daha fazla yorum yükle",
+        "tools": "Aletler",
+        "parts": "Parçalar",
     },
     "it": {
         "written_by": "Scritto Da:",
@@ -500,6 +659,13 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Pubblicato: ",
         "teardown": "Smontaggio",
+        "comments_count_before": "",
+        "comments_count_after": " commenti",
+        "comments_count_one": "Un commento",
+        "comments_stats_title": "Commenti: ",
+        "comments_show_more": "Carica altri commenti",
+        "tools": "Strumenti",
+        "parts": "Ricambi",
     },
     "es": {
         "written_by": "Escrito Por:",
@@ -518,12 +684,127 @@ GUIDE_LABELS = {
         "member_since_after": "",
         "published": "Publicado: ",
         "teardown": "Desmontaje",
+        "comments_count_before": "",
+        "comments_count_after": " comentarios",
+        "comments_count_one": "Un comentario",
+        "comments_stats_title": "Comentarios: ",
+        "comments_show_more": "Cargar más comentarios",
+        "tools": "Herramientas",
+        "parts": "Partes",
     },
 }
 
 
+USER_LABELS = {
+    "en": {
+        "reputation": "Reputation",
+        "member_since": "Member Since ",
+        "member_since_after": "",
+    },
+    "fr": {
+        "reputation": "Réputation",
+        "member_since": "Membre depuis ",
+        "member_since_after": "",
+    },
+    "pt": {
+        "reputation": "Reputação",
+        "member_since": "Membro desde ",
+        "member_since_after": "",
+    },
+    "de": {
+        "reputation": "Reputation",
+        "member_since": "Mitglied seit ",
+        "member_since_after": "",
+    },
+    "ko": {
+        "reputation": "평판",
+        "member_since_before": "",
+        "member_since_after": " 부터 회원",
+    },
+    "zh": {
+        "reputation": "信誉积分",
+        "member_since_before": "",
+        "member_since_after": " 注册",
+    },
+    "ru": {
+        "reputation": "Репутация",
+        "member_since_before": "Пользователь с ",
+        "member_since_after": "",
+    },
+    "nl": {
+        "reputation": "Reputatie",
+        "member_since_before": "Lid sinds ",
+        "member_since_after": "",
+    },
+    "ja": {
+        "reputation": "ポイント",
+        "member_since_before": "メンバー登録日 ",
+        "member_since_after": "",
+    },
+    "tr": {
+        "reputation": "İtibar",
+        "member_since_before": "Üyelik tarihi: ",
+        "member_since_after": "",
+    },
+    "it": {
+        "reputation": "Reputazione",
+        "member_since_before": "Membro dal ",
+        "member_since_after": "",
+    },
+    "es": {
+        "reputation": "Reputación",
+        "member_since_before": "Miembro Desde ",
+        "member_since_after": "",
+    },
+}
+
+NOT_YET_AVAILABLE = [
+    "team",
+    "wiki",
+    "answers",
+    "contribute",
+    "document",
+    "help",
+    "aide",
+    "item",
+    "mac-parts",
+    "troubleshoot",
+    "userwiki",
+    "users",
+    "stories",
+    "blog",
+    "ewaste",
+    "pledge",
+    "right",
+    "manifesto",
+    "tools",
+    "user/contributions",
+    "guide/document",
+    "guide/first-look",
+    "guide/how+to+sold",
+    "news",
+    "kits",
+    "teardown",
+    "vue+%c3%89clat%c3%a9e",
+    "r%c3%a9ponses",
+    "article",
+]
+
+UNAVAILABLE_OFFLINE = [
+    "store",
+    "boutique",
+    "tienda",
+    "products",
+    "game-console-parts",
+    "guide/survey",
+    "upgrade/laptop",
+    "search",
+]
+
 API_PREFIX = "/api/2.0"
 
+UNAVAILABLE_OFFLINE_INFOS = ["toolkits"]
+
 
 @dataclass
 class Conf:
@@ -553,6 +834,9 @@ class Conf:
     no_guide: Optional[bool] = False
     infos: Set[str] = field(default_factory=set)
     no_info: Optional[bool] = False
+    users: Set[str] = field(default_factory=set)
+    no_user: Optional[bool] = False
+    no_cleanup: Optional[bool] = False
 
     # filesystem
     _output_dir: Optional[str] = "."
