@@ -224,6 +224,22 @@ def main():
         default=False,
     )
 
+    parser.add_argument(
+        "--user",
+        help="Only scrape this user (can be specified multiple times). "
+        "Specify the userid",
+        dest="users",
+        action="append",
+    )
+
+    parser.add_argument(
+        "--no-user",
+        help="Do not scrape any user.",
+        dest="no_user",
+        action="store_true",
+        default=False,
+    )
+
     parser.add_argument(
         "--scrape-only-first-items",
         help="Scrape only first items of every type.",
@@ -232,6 +248,14 @@ def main():
         default=False,
     )
 
+    parser.add_argument(
+        "--no-cleanup",
+        help="Do not cleanup HTML content.",
+        dest="no_cleanup",
+        action="store_true",
+        default=False,
+    )
+
     args = parser.parse_args()
     Global.set_debug(args.debug)
 
