@@ -2,11 +2,11 @@
 # -*- coding: utf-8 -*-
 # vim: ai ts=4 sts=4 et sw=4 nu
 
+import hashlib
 import io
 import pathlib
 import re
 import urllib.parse
-from typing import Optional
 
 from kiwixstorage import KiwixStorage, NotFoundError
 from PIL import Image
@@ -25,8 +25,7 @@ class Imager:
         self.aborted = False
         # list of source URLs that we've processed and added to ZIM
         self.handled = set()
-        self.nb_requested = 0
-        self.nb_done = 0
+        self.dedup_items = dict()
 
         Global.img_executor.start()
 
@@ -57,13 +56,18 @@ class Imager:
         )
 
     def get_path_for(self, url: urllib.parse.ParseResult) -> str:
-        return "images/{}".format(re.sub(r"^(https?)://", r"\1/", url.geturl()))
+        url_with_only_path = urllib.parse.ParseResult(
+            scheme=url.scheme,
+            netloc=url.netloc,
+            path=url.path,
+            query="",
+            params="",
+            fragment="",
+        )
+        unquoted_url = urllib.parse.unquote(url_with_only_path.geturl())
+        return "images/{}".format(re.sub(r"^(https?)://", r"\1/", unquoted_url))
 
-    def defer(
-        self,
-        url: str,
-        path: Optional[str] = None,
-    ) -> str:
+    def defer(self, url: str) -> str:
         """request full processing of url, returning in-zim path immediately"""
 
         # find actual URL should it be from a provider
@@ -77,15 +81,13 @@ class Imager:
             logger.warning(f"Not supporting image URL `{url.geturl()}`. Skipping")
             return
 
-        # skip processing if we already processed it or have it in pipe
-        path = self.get_path_for(url) if path is None else path
+        path = self.get_path_for(url)
 
         if path in self.handled:
             return path
 
         # record that we are processing this one
         self.handled.add(path)
-        self.nb_requested += 1
 
         Global.img_executor.submit(
             self.process_image,
@@ -97,10 +99,34 @@ class Imager:
 
         return path
 
-    def once_done(self):
-        """default callback for single image processing"""
-        self.nb_done += 1
-        logger.debug(f"Images {self.nb_done}/{self.nb_requested}")
+    def check_for_duplicate(self, path, content):
+        digest = hashlib.sha256(content).digest()
+        if digest in self.dedup_items:
+            return self.dedup_items[digest]
+        self.dedup_items[digest] = path
+        return None
+
+    def add_image_to_zim(self, path, content, mimetype):
+        duplicate_path = self.check_for_duplicate(path, content)
+        with Global.lock:
+            if duplicate_path:
+                Global.creator.add_redirect(
+                    path=path,
+                    target_path=duplicate_path,
+                )
+            else:
+                Global.creator.add_item_for(
+                    path=path,
+                    content=content,
+                    mimetype=mimetype,
+                )
+
+    def add_missing_image_to_zim(self, path):
+        with Global.lock:
+            Global.creator.add_redirect(
+                path=path,
+                target_path="assets/NoImage_300x225.jpg",
+            )
 
     def process_image(self, url: str, path: str, mimetype: str) -> str:
         """download image from url or S3 and add to Zim at path. Upload if req."""
@@ -110,19 +136,33 @@ class Imager:
 
         # just download, optimize and add to ZIM if not using S3
         if not Global.conf.s3_url:
-            with Global.lock:
-                Global.creator.add_item_for(
-                    path=path,
-                    content=self.get_image_data(url.geturl()).getvalue(),
-                    mimetype=mimetype,
-                    callback=self.once_done,
+            try:
+                fileobj = self.get_image_data(url.geturl())
+            except Exception as exc:
+                logger.error(
+                    f"Failed to download/convert/optim source  at {url.geturl()}"
                 )
+                logger.exception(exc)
+                self.add_missing_image_to_zim(
+                    path=path,
+                )
+                return path
+
+            self.add_image_to_zim(
+                path=path,
+                content=fileobj.getvalue(),
+                mimetype=mimetype,
+            )
+
             return path
 
         # we are using S3 cache
         ident = get_version_ident_for(url.geturl())
         if ident is None:
             logger.error(f"Unable to query {url.geturl()}. Skipping")
+            self.add_missing_image_to_zim(
+                path=path,
+            )
             return path
 
         # key = self.get_s3_key_for(url.geturl())
@@ -142,13 +182,11 @@ class Imager:
             logger.exception(exc)
             download_failed = True
         else:
-            with Global.lock:
-                Global.creator.add_item_for(
-                    path=path,
-                    content=fileobj.getvalue(),
-                    mimetype=mimetype,
-                    callback=self.once_done,
-                )
+            self.add_image_to_zim(
+                path=path,
+                content=fileobj.getvalue(),
+                mimetype=mimetype,
+            )
             return path
 
         # we're using S3 but don't have it or failed to download
@@ -158,15 +196,16 @@ class Imager:
         except Exception as exc:
             logger.error(f"Failed to download/convert/optim source  at {url.geturl()}")
             logger.exception(exc)
+            self.add_missing_image_to_zim(
+                path=path,
+            )
             return path
 
-        with Global.lock:
-            Global.creator.add_item_for(
-                path=path,
-                content=fileobj.getvalue(),
-                mimetype=mimetype,
-                callback=self.once_done,
-            )
+        self.add_image_to_zim(
+            path=path,
+            content=fileobj.getvalue(),
+            mimetype=mimetype,
+        )
 
         # only upload it if we didn't have it in cache
         if not download_failed:
