@@ -16,7 +16,7 @@ class ScraperHomepage(ScraperGeneric):
 
     def setup(self):
         self.homepage_template = Global.env.get_template("home.html")
-        self.placeholder_template = Global.env.get_template("placeholder.html")
+        self.not_here_template = Global.env.get_template("not_here.html")
 
     def get_items_name(self):
         return "home"
@@ -28,6 +28,10 @@ class ScraperHomepage(ScraperGeneric):
         soup, _ = get_soup("/Guide")
         return soup
 
+    def add_item_redirect(self, item_key, item_data, redirect_kind):
+        logger.warning("Not supposed to add a redirect for a home item")
+        return
+
     def process_one_item(self, item_key, item_data, item_content):
         soup = item_content
 
@@ -42,14 +46,6 @@ class ScraperHomepage(ScraperGeneric):
             "sub_categories": self._extract_sub_categories_from_page(soup),
         }
 
-        for fc in home_content["featured_categories"]:
-            image_path = Global.imager.defer(url=fc["img_url"])
-            fc["img_path"] = image_path
-
-        home_content["callout"]["img_path"] = Global.imager.defer(
-            url=home_content["callout"]["img_url"]
-        )
-
         logger.debug(
             "Content extracted from /Guide:\n" f"{json.dumps(home_content,indent=2)}"
         )
@@ -60,29 +56,91 @@ class ScraperHomepage(ScraperGeneric):
             label=HOME_LABELS[Global.conf.lang_code],
         )
 
-        placeholder = self.placeholder_template.render(
-            home_content=home_content,
+        not_scrapped = self.not_here_template.render(
             metadata=Global.metadata,
-            label=HOME_LABELS[Global.conf.lang_code],
+            kind="not_scrapped",
+        )
+
+        external_content = self.not_here_template.render(
+            metadata=Global.metadata,
+            kind="external_content",
+        )
+
+        unavailable_offline = self.not_here_template.render(
+            metadata=Global.metadata,
+            kind="unavailable_offline",
+        )
+
+        not_yet_available = self.not_here_template.render(
+            metadata=Global.metadata,
+            kind="not_yet_available",
+        )
+
+        missing = self.not_here_template.render(
+            metadata=Global.metadata,
+            kind="missing",
+        )
+
+        error_content = self.not_here_template.render(
+            metadata=Global.metadata,
+            kind="error",
         )
 
         with Global.lock:
             Global.creator.add_item_for(
-                path="home/home.html",
+                path="home/home",
                 title=Global.conf.title,
                 content=homepage,
                 mimetype="text/html",
                 is_front=True,
             )
 
-            Global.creator.add_redirect(
-                path=DEFAULT_HOMEPAGE, target_path="home/home.html"
+            Global.creator.add_redirect(path=DEFAULT_HOMEPAGE, target_path="home/home")
+
+            Global.creator.add_item_for(
+                path="home/not_scrapped",
+                title=Global.conf.title,
+                content=not_scrapped,
+                mimetype="text/html",
+                is_front=False,
             )
 
             Global.creator.add_item_for(
-                path="home/placeholder.html",
-                title="Placeholder",
-                content=placeholder,
+                path="home/external_content",
+                title=Global.conf.title,
+                content=external_content,
+                mimetype="text/html",
+                is_front=False,
+            )
+
+            Global.creator.add_item_for(
+                path="home/unavailable_offline",
+                title=Global.conf.title,
+                content=unavailable_offline,
+                mimetype="text/html",
+                is_front=False,
+            )
+
+            Global.creator.add_item_for(
+                path="home/not_yet_available",
+                title=Global.conf.title,
+                content=not_yet_available,
+                mimetype="text/html",
+                is_front=False,
+            )
+
+            Global.creator.add_item_for(
+                path="home/missing",
+                title=Global.conf.title,
+                content=missing,
+                mimetype="text/html",
+                is_front=False,
+            )
+
+            Global.creator.add_item_for(
+                path="home/error",
+                title=Global.conf.title,
+                content=error_content,
                 mimetype="text/html",
                 is_front=False,
             )
